@@ -20,7 +20,7 @@
 #include "kget_debug.h"
 #include <qdebug.h>
 
-K_PLUGIN_FACTORY_WITH_JSON(KGetFactory, "kget_metalinkfactory.json", registerPlugin<MetalinkFactory>();)
+K_PLUGIN_CLASS_WITH_JSON(MetalinkFactory, "kget_metalinkfactory.json")
 
 MetalinkFactory::MetalinkFactory(QObject *parent, const QVariantList &args)
   : TransferFactory(parent, args)
